@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.2.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.6.2"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -69,8 +69,8 @@
 #define yynerrs         gth_albumtheme_yynerrs
 
 /* Copy the first part of user declarations.  */
-/* Line 336 of yacc.c  */
-#line 1 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 371 of yacc.c  */
+#line 1 "../../../extensions/webalbums/albumtheme.y"
 
 /*
  *  GThumb
@@ -106,7 +106,7 @@ int   gth_albumtheme_yywrap  (void);
 #define YYERROR_VERBOSE 1
 
 
-/* Line 336 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 111 "albumtheme.c"
 
 # ifndef YY_NULL
@@ -125,10 +125,7 @@ int   gth_albumtheme_yywrap  (void);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* In a future release of Bison, this section will be replaced
-   by #include "".  */
-#ifndef GTH_ALBUMTHEME_YY_
-# define GTH_ALBUMTHEME_YY_
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -169,8 +166,8 @@ extern int gth_albumtheme_yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 350 of yacc.c  */
-#line 37 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 387 of yacc.c  */
+#line 37 "../../../extensions/webalbums/albumtheme.y"
 
 	char         *text;
 	int           ivalue;
@@ -182,8 +179,8 @@ typedef union YYSTYPE
 	GthLoop      *loop;
 
 
-/* Line 350 of yacc.c  */
-#line 187 "albumtheme.c"
+/* Line 387 of yacc.c  */
+#line 184 "albumtheme.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -206,12 +203,12 @@ int gth_albumtheme_yyparse ();
 #endif
 #endif /* ! YYPARSE_PARAM */
 
-#endif /* !GTH_ALBUMTHEME_YY_  */
+
 
 /* Copy the second part of user declarations.  */
 
-/* Line 353 of yacc.c  */
-#line 215 "albumtheme.c"
+/* Line 390 of yacc.c  */
+#line 212 "albumtheme.c"
 
 #ifdef short
 # undef short
@@ -264,24 +261,24 @@ typedef short int yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -658,10 +655,10 @@ static const yytype_int8 yytable[] =
       63,    48,    49,     0,    90,    50,    51,    52,    53
 };
 
-#define yypact_value_is_default(yystate) \
-  ((yystate) == (-39))
+#define yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-39)))
 
-#define yytable_value_is_error(yytable_value) \
+#define yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const yytype_int8 yycheck[] =
@@ -754,47 +751,18 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
-    do                                                                  \
-      if (YYID (N))                                                     \
-        {                                                               \
-          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
-          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
-          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
-          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
-        }                                                               \
-      else                                                              \
-        {                                                               \
-          (Current).first_line   = (Current).last_line   =              \
-            YYRHSLOC (Rhs, 0).last_line;                                \
-          (Current).first_column = (Current).last_column =              \
-            YYRHSLOC (Rhs, 0).last_column;                              \
-        }                                                               \
-    while (YYID (0))
-#endif
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
-
-
 
 /* This macro is provided for backward compatibility. */
-
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX yylex (YYLEX_PARAM)
 #else
@@ -857,7 +825,7 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
   switch (yytype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1099,7 +1067,6 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 {
   YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
-  YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *yyformat = YY_NULL;
@@ -1162,11 +1129,13 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
-                if (! (yysize <= yysize1
-                       && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                yysize = yysize1;
+                {
+                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
+                  if (! (yysize <= yysize1
+                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  yysize = yysize1;
+                }
               }
         }
     }
@@ -1186,10 +1155,12 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 # undef YYCASE_
     }
 
-  yysize1 = yysize + yystrlen (yyformat);
-  if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  yysize = yysize1;
+  {
+    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
+    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    yysize = yysize1;
+  }
 
   if (*yymsg_alloc < yysize)
     {
@@ -1249,7 +1220,7 @@ yydestruct (yymsg, yytype, yyvaluep)
     {
 
       default:
-	break;
+        break;
     }
 }
 
@@ -1259,8 +1230,17 @@ yydestruct (yymsg, yytype, yyvaluep)
 /* The lookahead symbol.  */
 int yychar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE yylval;
+YYSTYPE yylval YY_INITIAL_VALUE(yyval_default);
 
 /* Number of syntax errors so far.  */
 int yynerrs;
@@ -1318,7 +1298,7 @@ yyparse ()
   int yyn;
   int yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
+  int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE yyval;
@@ -1336,9 +1316,8 @@ yyparse ()
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
-  yytoken = 0;
-  yyss = yyssa;
-  yyvs = yyvsa;
+  yyssp = yyss = yyssa;
+  yyvsp = yyvs = yyvsa;
   yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1347,13 +1326,6 @@ yyparse ()
   yyerrstatus = 0;
   yynerrs = 0;
   yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  yyssp = yyss;
-  yyvsp = yyvs;
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1494,7 +1466,9 @@ yybackup:
   yychar = YYEMPTY;
 
   yystate = yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto yynewstate;
 
@@ -1531,8 +1505,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-/* Line 1787 of yacc.c  */
-#line 77 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 77 "../../../extensions/webalbums/albumtheme.y"
     {
 			yy_parsed_doc = (yyvsp[(1) - (1)].list);
 			if (yy_parsed_doc == NULL)
@@ -1543,8 +1517,8 @@ yyreduce:
     break;
 
   case 3:
-/* Line 1787 of yacc.c  */
-#line 86 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 86 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), gth_tag_new_html ((yyvsp[(1) - (2)].text)));
 			g_free ((yyvsp[(1) - (2)].text));
@@ -1552,24 +1526,24 @@ yyreduce:
     break;
 
   case 4:
-/* Line 1787 of yacc.c  */
-#line 91 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 91 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		}
     break;
 
   case 5:
-/* Line 1787 of yacc.c  */
-#line 95 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 95 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		}
     break;
 
   case 6:
-/* Line 1787 of yacc.c  */
-#line 99 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 99 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthTag *tag;
 
@@ -1580,8 +1554,8 @@ yyreduce:
     break;
 
   case 7:
-/* Line 1787 of yacc.c  */
-#line 107 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 107 "../../../extensions/webalbums/albumtheme.y"
     {
 			GList  *cond_list;
 			GthTag *tag;
@@ -1597,16 +1571,16 @@ yyreduce:
     break;
 
   case 8:
-/* Line 1787 of yacc.c  */
-#line 120 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 120 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 9:
-/* Line 1787 of yacc.c  */
-#line 124 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 124 "../../../extensions/webalbums/albumtheme.y"
     {
 			/*if ($2 != NULL)
 				gth_parsed_doc_free ($2);*/
@@ -1615,8 +1589,8 @@ yyreduce:
     break;
 
   case 10:
-/* Line 1787 of yacc.c  */
-#line 131 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 131 "../../../extensions/webalbums/albumtheme.y"
     {
 			if (g_str_equal ((yyvsp[(2) - (3)].text), "thumbnail_caption")) {
 				(yyval.loop) = gth_loop_new (GTH_TAG_FOR_EACH_THUMBNAIL_CAPTION);
@@ -1632,8 +1606,8 @@ yyreduce:
     break;
 
   case 11:
-/* Line 1787 of yacc.c  */
-#line 144 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 144 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.loop) = gth_range_loop_new ();
 			gth_range_loop_set_range (GTH_RANGE_LOOP ((yyval.loop)), (yyvsp[(2) - (7)].text), (yyvsp[(4) - (7)].expr), (yyvsp[(6) - (7)].expr));
@@ -1645,24 +1619,24 @@ yyreduce:
     break;
 
   case 12:
-/* Line 1787 of yacc.c  */
-#line 154 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 154 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		}
     break;
 
   case 13:
-/* Line 1787 of yacc.c  */
-#line 158 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 158 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		}
     break;
 
   case 14:
-/* Line 1787 of yacc.c  */
-#line 163 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 163 "../../../extensions/webalbums/albumtheme.y"
     {
 			gth_condition_add_document ((yyvsp[(1) - (3)].cond), (yyvsp[(2) - (3)].list));
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].cond));
@@ -1670,32 +1644,32 @@ yyreduce:
     break;
 
   case 15:
-/* Line 1787 of yacc.c  */
-#line 168 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 168 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 16:
-/* Line 1787 of yacc.c  */
-#line 173 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 173 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		}
     break;
 
   case 17:
-/* Line 1787 of yacc.c  */
-#line 177 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 177 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		}
     break;
 
   case 18:
-/* Line 1787 of yacc.c  */
-#line 182 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 182 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr      *else_expr;
 			GthCondition *cond;
@@ -1710,24 +1684,24 @@ yyreduce:
     break;
 
   case 19:
-/* Line 1787 of yacc.c  */
-#line 194 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 194 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = NULL;
 		}
     break;
 
   case 22:
-/* Line 1787 of yacc.c  */
-#line 205 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 205 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.tag) = gth_tag_new (GTH_TAG_SET_VAR, (yyvsp[(2) - (3)].list));
 		}
     break;
 
   case 23:
-/* Line 1787 of yacc.c  */
-#line 210 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 210 "../../../extensions/webalbums/albumtheme.y"
     {
 			if (gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text)) == GTH_TAG_EVAL) {
 				GthExpr *e;
@@ -1778,8 +1752,8 @@ yyreduce:
     break;
 
   case 24:
-/* Line 1787 of yacc.c  */
-#line 258 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 258 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthTagType tag_type = gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text));
 			if (tag_type == GTH_TAG_INVALID) {
@@ -1791,24 +1765,24 @@ yyreduce:
     break;
 
   case 25:
-/* Line 1787 of yacc.c  */
-#line 268 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 268 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].attribute));
 		}
     break;
 
   case 26:
-/* Line 1787 of yacc.c  */
-#line 272 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 272 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 27:
-/* Line 1787 of yacc.c  */
-#line 277 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 277 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_expression ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].expr));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1816,8 +1790,8 @@ yyreduce:
     break;
 
   case 28:
-/* Line 1787 of yacc.c  */
-#line 282 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 282 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_string ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].text));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1826,8 +1800,8 @@ yyreduce:
     break;
 
   case 29:
-/* Line 1787 of yacc.c  */
-#line 288 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 288 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, 1);
@@ -1837,40 +1811,40 @@ yyreduce:
     break;
 
   case 30:
-/* Line 1787 of yacc.c  */
-#line 296 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 296 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].expr));
 		}
     break;
 
   case 31:
-/* Line 1787 of yacc.c  */
-#line 300 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 300 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend (NULL, (yyvsp[(1) - (1)].expr));
 		}
     break;
 
   case 32:
-/* Line 1787 of yacc.c  */
-#line 304 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 304 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 33:
-/* Line 1787 of yacc.c  */
-#line 309 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 309 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (3)].expr);
 		}
     break;
 
   case 34:
-/* Line 1787 of yacc.c  */
-#line 313 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 313 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1886,8 +1860,8 @@ yyreduce:
     break;
 
   case 35:
-/* Line 1787 of yacc.c  */
-#line 326 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 326 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1903,8 +1877,8 @@ yyreduce:
     break;
 
   case 36:
-/* Line 1787 of yacc.c  */
-#line 339 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 339 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1920,8 +1894,8 @@ yyreduce:
     break;
 
   case 37:
-/* Line 1787 of yacc.c  */
-#line 352 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 352 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1937,8 +1911,8 @@ yyreduce:
     break;
 
   case 38:
-/* Line 1787 of yacc.c  */
-#line 365 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 365 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1954,8 +1928,8 @@ yyreduce:
     break;
 
   case 39:
-/* Line 1787 of yacc.c  */
-#line 378 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 378 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1971,16 +1945,16 @@ yyreduce:
     break;
 
   case 40:
-/* Line 1787 of yacc.c  */
-#line 391 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 391 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
 		}
     break;
 
   case 41:
-/* Line 1787 of yacc.c  */
-#line 395 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 395 "../../../extensions/webalbums/albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NEG);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -1988,8 +1962,8 @@ yyreduce:
     break;
 
   case 42:
-/* Line 1787 of yacc.c  */
-#line 400 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 400 "../../../extensions/webalbums/albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NOT);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -1997,8 +1971,8 @@ yyreduce:
     break;
 
   case 43:
-/* Line 1787 of yacc.c  */
-#line 405 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 405 "../../../extensions/webalbums/albumtheme.y"
     { /* function call */
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (4)].text));
@@ -2018,8 +1992,8 @@ yyreduce:
     break;
 
   case 44:
-/* Line 1787 of yacc.c  */
-#line 422 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 422 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (1)].text));
@@ -2029,8 +2003,8 @@ yyreduce:
     break;
 
   case 45:
-/* Line 1787 of yacc.c  */
-#line 429 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 429 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_string (e, (yyvsp[(2) - (3)].text));
@@ -2040,8 +2014,8 @@ yyreduce:
     break;
 
   case 46:
-/* Line 1787 of yacc.c  */
-#line 436 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1792 of yacc.c  */
+#line 436 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, (yyvsp[(1) - (1)].ivalue));
@@ -2050,8 +2024,8 @@ yyreduce:
     break;
 
 
-/* Line 1787 of yacc.c  */
-#line 2055 "albumtheme.c"
+/* Line 1792 of yacc.c  */
+#line 2029 "albumtheme.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2214,7 +2188,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
@@ -2280,8 +2256,8 @@ yyreturn:
 }
 
 
-/* Line 2048 of yacc.c  */
-#line 443 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 2055 of yacc.c  */
+#line 443 "../../../extensions/webalbums/albumtheme.y"
 
 
 
